OC.L10N.register(
    "settings",
    {
    "{actor} added you to group {group}" : "{actor} lisas sind gruppi {group}",
    "You added {user} to group {group}" : "Sa lisasid kasutaja {user} gruppi {group}",
    "{actor} added {user} to group {group}" : "{actor} lisas kasutaja {user} gruppi {group}",
    "An administrator added you to group {group}" : "Peakasutaja lisas sind gruppi {group}",
    "An administrator added {user} to group {group}" : "Peakasutaja lisas kasutaja {user} gruppi {group}",
    "{actor} removed you from group {group}" : "{actor} eemaldas sind grupist {group}",
    "You removed {user} from group {group}" : "Sa eemaldasid kasutaja {user} grupist {group}",
    "{actor} removed {user} from group {group}" : "{actor} eemaldas kasutaja {user} grupist {group}",
    "An administrator removed you from group {group}" : "Peakasutaja eemaldas sind grupist {group}",
    "An administrator removed {user} from group {group}" : "Peakasutaja eemaldas kasutaja {user} grupist {group}",
    "Your <strong>group memberships</strong> were modified" : "Sinu <strong>grupide liikmelisus</strong> on muutunud",
    "{actor} changed your password" : "{actor} muutis sinu salasõna",
    "You changed your password" : "Sa muutsid oma salasõna",
    "Your password was reset by an administrator" : "Peakasutaja lähtestas sinu salasõna",
    "Your password was reset" : "Sinu salasõna on lähtestatud",
    "{actor} changed your email address" : "{actor} muutis sinu e-posti aadressi",
    "You changed your email address" : "Sa muutsid oma e-posti aadressi",
    "Your email address was changed by an administrator" : "Peakasutaja muutis sinu e-posti aadressi",
    "You created an app password for a session named \"{token}\"" : "Tegid rakenduse salasõna sessioonile nimega „{token}“",
    "An administrator created an app password for a session named \"{token}\"" : "Peakasutaja tegi rakenduse salasõna sessioonile nimega „{token}“",
    "You deleted app password \"{token}\"" : "Sina kustutasid rakenduse salasõna „{token}“",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Sa muutsid rakenduse salasõna: „{token}“ → „{newToken}“",
    "You granted filesystem access to app password \"{token}\"" : "Sa lubasid failisüsteemi ligipääsu rakenduse salasõnale „{token}“",
    "You revoked filesystem access from app password \"{token}\"" : "Sa keelasid failisüsteemi ligipääsu rakenduse salasõnale „{token}“",
    "Security" : "Turvalisus",
    "You successfully logged in using two-factor authentication (%1$s)" : "Kasutades kaheastmelist autentimist sisselogimine õnnestus (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Sisselogimiskatse kaheastmelise autentimisega ei õnnestunud (%1$s)",
    "Remote wipe was started on %1$s" : "Kaugkustutamine algas: %1$s",
    "Remote wipe has finished on %1$s" : "Kaugkustutamine lõppes: %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Sinu <strong>salasõna</strong> või <strong>e-posti aadress</strong> on muudetud",
    "Settings" : "Seadistused",
    "Could not remove app." : "Rakenduse eemaldamine ei õnnestunud.",
    "Could not update app." : "Rakenduse uuendamine ei õnnestunud.",
    "One time login" : "Ühekordse sisselogimise võimalus",
    "QR Code login" : "QR-koodiga sisselogimine",
    "Wrong password" : "Vale salasõna",
    "Unable to change personal password" : "Isikliku salasõna muutmine ei õnnestu",
    "Saved" : "Salvestatud",
    "No Login supplied" : "Kasutajanimi on sisestamata",
    "Unable to change password" : "Ei suuda salasõna muuta",
    "Unable to change password. Password too long." : "Salasõna muutmine ei õnnestu. Salasõna on liiga pikk.",
    "Authentication error" : "Autentimise viga",
    "Please provide an admin recovery password; otherwise, all account data will be lost." : "Palun sisesta peakasutaja taastesalasõna - vastasel juhul kaotad ligipääsu kõikidele kasutajakonto andmetele.",
    "Wrong admin recovery password. Please check the password and try again." : "Vale peakasutaja taastesalasõna. Palun kontrolli salasõna ning proovi uuesti.",
    "Backend does not support password change, but the encryption of the account key was updated." : "Taustateenus ei toeta salasõna muutmist, aga kasutajakonto võtme krüptimine sai uuendatud.",
    "Administrator documentation" : "Dokumentatsioon peakasutajale",
    "User documentation" : "Kasutaja dokumentatsioon",
    "Nextcloud help overview" : "Nextcloudi abiteabe ülevaade",
    "Invalid SMTP password." : "Vale SMTP salasõna.",
    "Email setting test" : "E-posti sätete kontroll",
    "Well done, %s!" : "Hästi tehtud, %s!",
    "If you received this email, the email configuration seems to be correct." : "Kui said selle kirja, näib e-posti seadistus õige.",
    "Email could not be sent. Check your mail server log" : "E-kirja saatmine ebaõnnestus. Kontrolli oma meiliserveri logi",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "E-kirja saatmisel tekkis viga. Palun vaata seadistused üle. (Viga: %s)",
    "You need to set your account email before being able to send test emails. Go to %s for that." : "Enne e-kirjade testsaatmist pead seadistama oma e-posti aadressi. Selleks vaata siia: %s.",
    "Recently active" : "Hiljuti aktiivne",
    "Disabled accounts" : "Väljalülitatud kasutajakonto",
    "Invalid account" : "Vigane kasutajakonto",
    "Invalid mail address" : "Vigane e-posti aadress",
    "Settings saved" : "Seadistused on salvestatud",
    "Unable to change full name" : "Täisnime muutmine ebaõnnestus",
    "Unable to change email address" : "E-posti aadressi muutmine ebaõnnestus",
    "Unable to set invalid phone number" : "Vigase telefoninumbri lisamine pole võimalik",
    "Unable to set invalid website" : "Vigase veebisaidi lisamine pole võimalik",
    "Some account data was invalid" : "Osa kasutajakonto andmeid olid vigased",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Selleks, et tuvastada, et tegemist tõesti on sinu X-i / Twitteri kasutajakontoga, palun postita oma kontole järgnev säuts (palun kontrolli, et sinna ei satuks reavahetusi):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Sinu veebisaidi õigsuse kontrolliks palun salvesta järgnev sisu oma saiti asukohta „.well-known/CloudIdVerificationCode.txt“ (ning kontrolli, et järgnev tekst on seal failis ühel real):",
    "%1$s changed your password on %2$s." : "%1$s muutis sinu salasõna teenuses %2$s.",
    "Your password on %s was changed." : "Sinu %s salasõna on muudetud.",
    "Your password on %s was reset by an administrator." : "Peakasutaja lähtestas sinu %s salasõna.",
    "Your password on %s was reset." : "Sinu salasõna „%s“ sai lähtestatud.",
    "Password for %1$s changed on %2$s" : "%1$s salasõna teenuses %2$s on muutunud",
    "Password changed for %s" : "%s salasõna on muudetud",
    "If you did not request this, please contact an administrator." : "Kui sa pole seda taotlenud, võta ühendust peakasutajaga.",
    "Your email address on %s was changed." : "Sinu %s e-posti aadressi muudeti.",
    "Your email address on %s was changed by an administrator." : "Peakasutaja muutis sinu %s e-posti aadressi.",
    "Email address for %1$s changed on %2$s" : "%1$s e-posti aadress muudetud %2$s",
    "Email address changed for %s" : "%s e-posti aadress muudetud",
    "The new email address is %s" : "Uus e-posti aadress on %s",
    "Your %s account was created" : "Sinu %s konto on loodud",
    "Welcome aboard" : "Tere tulemast",
    "Welcome aboard %s" : "Tere tulemast %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Tere tulemast oma %s kontole. Sa saad lisada, kaitsta ja jagada oma andmeid.",
    "Your Login is: %s" : "Sinu kasutajanimi on: %s",
    "Set your password" : "Sisesta oma salasõna",
    "Go to %s" : "Mine %s",
    "Install Client" : "Paigalda kliendiprogramm",
    "Logged in account must be a sub admin" : "Sisselogitud kasutajakonto peab olema peakasutajate alamgrupi liige",
    "Apps" : "Rakendused",
    "Personal" : "Isiklik",
    "Administration" : "Haldus",
    "Users" : "Kasutajad",
    "Additional settings" : "Lisaseadistused",
    "Assistant" : "Abiline",
    "Administration privileges" : "Peakasutaja õigused",
    "Groupware" : "Grupitöö",
    "Overview" : "Ülevaade",
    "Quick presets" : "Kiired eelseadistused",
    "Basic settings" : "Põhiseadistused",
    "Sharing" : "Jagamine",
    "Availability" : "Saadavus",
    "Calendar" : "Kalender",
    "Personal info" : "Isiklik info",
    "Mobile & desktop" : "Mobiil ja töölaud",
    "Artificial Intelligence" : "Tehisintellekt",
    "None / STARTTLS" : "Puudub / STARTTLS",
    "Email server" : "E-kirjade server",
    "Mail Providers" : "E-posti teenusepakkujad",
    "Mail provider enables sending emails directly through the user's personal email account. At present, this functionality is limited to calendar invitations. It requires Nextcloud Mail 4.1 and an email account in Nextcloud Mail that matches the user's email address in Nextcloud." : "Lisaks järgnevale üldisele valikule on võimalik ka isikliku e-postiikonto kasutamine. Hetkel toimib see võimalus vaid Nextcloudi kalendrikutsete puhul ning eelduseks on Nextcloud Mail 4.1 või suurem ning seal seadistatud e-postikonto vastab kasutaja e-postiaadressile Nextcloudi profiilis.",
    "Send emails using" : "E-kirjade saatmisel on kasutusel",
    "User's email account" : "Kasutaja seadistatud e-postikonto",
    "System email account" : "Süsteemis seadistatud e-postikonto",
    "Security & setup checks" : "Turva- ja paigalduse kontrollid",
    "Settings presets" : "Eelseadistused",
    "Background jobs" : "Taustal toimivad haldustoimingud",
    "Unlimited" : "Piiramatult",
    "Verifying" : "Kontrollin",
    "Verifying …" : "Kontrollin ...",
    "Verify" : "Kontrolli",
    "Allowed admin IP ranges" : "Süsteemihalduseks lubatud IP-aadresside vahemikud",
    "Admin IP filtering isn't applied." : "Süsteemihalduseks lubatud IP-aadresside vahemikud pole seadistatud.",
    "Configuration key \"%1$s\" expects an array (%2$s found). Admin IP range validation will not be applied." : "Seadistuste võtmes „%1$s“ peab olema kirjas massiiv ( aga leidsime „%2$s“). Süsteemihalduseks lubatud IP-aadresside filtreerimine hetkel ei toimi.",
    "Configuration key \"%1$s\" contains invalid IP range(s): \"%2$s\"" : "Seadistuste võtmes „%1$s“ on vigane IP-aadressi(de) vahemik: „%2$s“",
    "Admin IP filtering is correctly configured." : "Süsteemihalduseks lubatud IP-aadresside filtreerimine on korrektselt seadistatud.",
    "App directories owner" : "Rakenduste kausta omanik",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:\n%s" : "Mõnede rakenduste kaustade omanik erinev kogu Nextcloudi serveri omanikust. Nii võib juhtuda, kui rakendused on  paigaldatud käsitsi. Palun kontrolli järgnevate rakenduste kaustade omanikke:\n%s",
    "App directories have the correct owner \"%s\"" : "Rakenduste kaustadel on korrektne omanik: „%s“",
    "Brute-force Throttle" : "Jõuründe piiramise meetmed",
    "Your remote address could not be determined." : "Sinu kaugaadressi tuvastamine ei õnnestunud.",
    "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly." : "Sinu seadme või arvuti aadress on tuvastatud kui „%s“ ja hetkel on selle aadressi puhul kasutusel jõuründe piiramise meetmed, mis aeglustavad erinevate päringute toimimist. Kui see kaugaadress pole sinu oma, siis see võib vihjata, et proksiserver pole korrektselt seadistatud.",
    "Your remote address \"%s\" is not brute-force throttled." : "Sinu „%s“ aadressil pole hetkel kasutusel jõuründe piiramise meetmed",
    "No altered files" : "Muudetud faile pole",
    "Some files have not passed the integrity check. {link1} {link2}" : "Mõned failid pole läbinud andmetervikluse kontrolli. {link1} {link2}",
    "List of invalid files…" : "Vigaste failide loend…",
    "Rescan…" : "Skaneeri uuesti…",
    "Database missing columns" : "Andmebaasis on puudu veerge",
    "Missing optional column \"%s\" in table \"%s\"." : "Mittekohustuslik veerg „%s“ on puudu tabelist „%s“.",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Andmebaasist  on puudu mõned täiendavad väljad. Kuna suurtesse tabelitesse uute veergude lisamine on ressursimahukas ja kui veerg ise soovituslik, siis see tihti jäetakse automaatse lisamise puhul vahele. Kasutades käsku „occ db:add-missing-columns“ saad need veerud sobilikul hetkel ise lisada. Peale lisamistmõne funktsionaalsuse kiirus ja kasutatavus võivad paraneda.",
    "Database missing indices" : "Andmebaasis on puudu mõned indeksid",
    "Missing indices:" : "Puuduvad indeksid:",
    "\"%s\" in table \"%s\"" : "„%s“ tabelis „%s“",
    "Database missing primary keys" : "Andmebaasis on puudu primaarvõtmed",
    "Missing primary key on table \"%s\"." : "Puuduv primaarvõti tabelis „%s“.",
    "Debug mode" : "Veaotsingu- ja silumisrežiim",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "See server töötab hetkel veaotsingu- ja silumisrežiimis. Palun kasuta seda vaid kohalikus arendustöös, kuid mitte tarbeserveris.",
    "Debug mode is disabled." : "Veaotsingu- ja silumisrežiim pole kasutusel.",
    "Default phone region" : "Telefonide vaikimisi piirkond",
    "Email test" : "E-kirjade saatmise test",
    "Mail delivery is disabled by instance config \"%s\"." : "Selles serveris piirab e-kirjade edasisaatmist seadistus „%s“.",
    "Email test was successfully sent" : "Testkirja saatmine õnnestus",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array." : "Serveri „trusted_proxies“ seadistus pole korrektne - seal peab leiduma massiiv, aga hetkel on midagi muud.",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array of IP addresses - optionally with range in CIDR notation." : "Sinu kasutatav „trusted_proxies“ seadistus pole korrektne - ta peaks olema IP-aadresside massiiv, kus soovi korral saad kasutada CIDR-vormingut vahemike kirjeldamiseks.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Sellel serveril puudub toimiv internetiühendus: mitmete otspunktidega ei ole leitavad. See tähendab, et mõned funktsionaalsused, nagu näiteks väliste andmehoidlate ühendamine, uuenduste teavitused või kolmandate osapoolte rakenduste paigaldamine ei tööta. Ligipääs failidele eemalt ning teavistuste saatmine e-kirjaga ei pruugi samuti toimida. Kui soovid kasutada täielikku funktsionaalsust, siis palun taga toimiv internetiühendus.",
    "Old server-side-encryption" : "Vana serveripoolne krüptimine",
    "Disabled" : "Keelatud",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Vana serveripoolse krüptimise vorming on kasutusel. Mes soovitame, et lülitad selle välja.",
    "Logging level" : "Logitase",
    "The %1$s configuration option must be a valid integer value." : "Seadistusvalik „%1$s“ peab olema korrektne täisarv.",
    "The logging level is set to debug level. Use debug level only when you have a problem to diagnose, and then reset your log level to a less-verbose level as it outputs a lot of information, and can affect your server performance." : "Logimistase on hetkel seatud veaotsinguks. Kasuta seda vaid siis, kui tõesti tegeled veaotsinguga ning peale seda muuda logimine jälle tavaliseks. Veaotsinguks vajalik logimine on väga väljundirikas ning võib mõjutada serveri jõudlust.",
    "Logging level configured correctly." : "Logimistase on korrektselt seadistatud",
    "Failed to write and read a value from local cache." : "Väärtuse lugemine kohalikust puhvrist ja kirjutamine sinna ei õnnestunud.",
    "Failed to write and read a value from distributed cache." : "Väärtuse lugemine hajutatud puhvrist ja kirjutamine sinna ei õnnestunud.",
    "Mimetype migrations available" : "MIME-tüüpide (failitüüpide) uuendamine on võimalik",
    "One or more mimetype migrations are available. Occasionally new mimetypes are added to better handle certain file types. Migrating the mimetypes take a long time on larger instances so this is not done automatically during upgrades. Use the command `occ maintenance:repair --include-expensive` to perform the migrations." : "Sul on võimalik teha üks või enam MIME-tüüpide uuendust. Vahetevahel lisame uusi MIME-tüüpe, mis tagavad failide mugavama ja parema kasutamise. Vastava uuenduse tegemiseks võib mahukates serverites kuluda palju aega ja seega seda ei tehta üldise uuenduse ajal automaatselt. Palun kasuta uuendamiseks käsku „occ maintenance:repair --include-expensive“.",
    "MySQL row format" : "MySQL-i rea vorming",
    "You are not using MySQL" : "Sa ei kasuta MySQL-i",
    "None of your tables use ROW_FORMAT=Compressed" : "Mitte ükski sinu tabelitest ei kasuta „ROW_FORMAT=Compressed“ tingimust",
    "Incorrect row format found in your database. ROW_FORMAT=Dynamic offers the best database performances for Nextcloud. Please update row format on the following list: %s." : "Sinu andmebaasis leidus vale rea vorming. Nextcloudi puhul tagab parima jõudluse „ROW_FORMAT=Dynamic“ seadistus. Palun uuenda järgnevas loendis näidatud ridade vorming: %s.",
    "PHP APCu configuration" : "PHP APCu seadistus",
    "Your APCu cache has been running full, consider increasing the apc.shm_size php setting." : "Sinu serveri PHP APCu puhver on on pidevalt täis. Lahenduseks palun kaalu PHP-seadistustest „apc.shm_size“ väärtuse suurendamist.",
    "Your APCu cache is almost full at %s%%, consider increasing the apc.shm_size php setting." : "Sinu serveri PHP APCu puhver on on üsna täis (%s%%). Lahenduseks palun kaalu PHP-seadistustest „apc.shm_size“ väärtuse suurendamist.",
    "PHP default charset" : "PHP vaikimisi märgistik",
    "PHP configuration option \"default_charset\" should be UTF-8" : "PHP seadistuse „default_charset“ väärtus peab olema UTF-8",
    "PHP set_time_limit" : "PHP set_time_limit",
    "The function is available." : "Funktsioon on saadaval.",
    "Freetype" : "Freetype",
    "Supported" : "Toetatud",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Sinu serverisse paigaldatud PHP-l puudub FreeType'i tugi ning selle tulemusena ei pruugi profiilipiltide lisamine ja kuvamine ja osa seadistuste liidesest toimida.",
    "PHP getenv" : "PHP getenv",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP ei tundu olevat süsteemsete keskkonnamuutujate pärimiseks korrektselt seadistatud. Test getenv(\"PATH\") abil tagastab tühja vastuse.",
    "PHP file size upload limit" : "PHP failide üleslaadimise mahupiir",
    "The PHP upload_max_filesize is too low. A size of at least %1$s is recommended. Current value: %2$s." : "PHP seadistuse „upload_max_filesize“ väärtus on liiga väike. Meie soovitatud väärtus: %1$s. Praegune väärtus: %2$s.",
    "The PHP post_max_size is too low. A size of at least %1$s is recommended. Current value: %2$s." : "PHP seadistuse „post_max_size“ väärtus on liiga väike. Meie soovitatud väärtus: %1$s. Praegune väärtus: %2$s.",
    "The PHP max_input_time is too low. A time of at least %1$s is recommended. Current value: %2$s." : "PHP seadistuse „max_input_time“ väärtus on liiga väike. Meie soovitatud väärtus: %1$s. Praegune väärtus: %2$s.",
    "The PHP max_execution_time is too low. A time of at least %1$s is recommended. Current value: %2$s." : "PHP seadistuse „max_execution_time“ väärtus on liiga väike. Meie soovitatud väärtus: %1$s. Praegune väärtus: %2$s.",
    "PHP memory limit" : "PHP mälukasutuse ülempiir",
    "The PHP memory limit is below the recommended value of %s. Some features or apps - including the Updater - may not function properly." : "PHP mälukasutuse piir on väiksem, muid soovitatav väärtus %s. Mõned funktsionaalsused või rakendused, sealhulgas uuendaja, ei pruugi toimida korrektselt.",
    "PHP modules" : "PHP lisamoodulid",
    "increases language translation performance and fixes sorting of non-ASCII characters" : "parandab jõudlust keelte tõlkimisel ja tagab korrektse järjestamise, kui kasutusel on mitte-ASCII tähemärgid",
    "for Argon2 for password hashing" : "Argon2-põhise salasõna räsimise jaoks",
    "required for SFTP storage and recommended for WebAuthn performance" : "nõutav SFTP andmeruumi jaoks ja soovitatav WebAuthn jõudluse jaoks",
    "This instance is missing some required PHP modules. It is required to install them: %s." : "Siit serverist on puudu mõned vajalikud PHP moodulid. On nõutav, et paigaldad alljärgnevad lisamoodulid: %s.",
    "The PHP OPcache module is not properly configured. %s." : "PHP OPcache'i moodul pole korrektselt seadistatud. %s.",
    "Correctly configured" : "Korrektselt seadistatud",
    "PHP version" : "PHP versioon",
    "You are currently running PHP %1$s. PHP %2$s is deprecated since Nextcloud %3$s. Nextcloud %4$s may require at least PHP %5$s. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "Sa kasutad hetkel PHP versiooni %1$s. PHP %2$s on aga alates Nexctcloudi versioonist %3$s kasutuselt eemaldatud. Nexctcloud %4$s eeldab, et PHP versioon on vähemalt %5$s. Palun uuenda oma server PHP Groupi poolt väljaantud ametliku PHP versioonini niipea, kui võimalik.",
    "You are currently running PHP %s." : "Sul on hetkel kasutusel PHP versioon %s.",
    "PHP \"output_buffering\" option" : "PHP eelistus „output_buffering“",
    "PHP configuration option \"output_buffering\" must be disabled" : "PHP seadistus „output_buffering“ peab olema lülitatud välja",
    "Push service" : "Tõuketeenus",
    "Valid enterprise license" : "Suurfirmade litsents",
    "Free push service" : "Tasuta tõuketeenus",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {link}." : "See on mittetoetatud Nextcloudi variant kogukonnale. Arvestades selle serveri parameetreid, pole jõudlus, töökindlus ja skaleeritavus garanteeritud. Meie tasuta teenuse ülekoormuse vältimiseks on tõuketeavituste arv piiratud. Nextcloud Enterprise versiooni eelistest loe siin: {link}.",
    "Random generator" : "Juhuslike arvude generaator",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons." : "PHP ei suutnud tuvastada piisavalt juhuslikku andmeallikat ja turvakaalutlustel me soovitame seda olukorda välistada.",
    "Secure" : "Turvaline",
    "Configuration file access rights" : "Ligipääsuõigused seadistuste failile",
    "Nextcloud configuration file is writable" : "Nextcloudi seadistusfail on on kirjutatav",
    "HTTP headers" : "HTTP-päringute päised",
    "- The `%1$s` HTTP header is not set to `%2$s`. Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "- HTTP päisekirje „%1$s“ väärtus pole „%2$s“. Osa teenusest ei pruugi seetõttu korralikult toimida ning me soovitame,, et teed vastava muudatuse.",
    "- The `%1$s` HTTP header is not set to `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "- HTTP päisekirje „%1$s“ väärtus pole „%2$s“. See on võimalik turva- ja privaatsusrisk ning me soovitame, et teed vastava muudatuse.",
    "- The `%1$s` HTTP header is not set to `%2$s`, `%3$s`, `%4$s`, `%5$s` or `%6$s`. This can leak referer information. See the {w3c-recommendation}." : "- HTTP päisekirje „%1$s“ väärtus pole „%2$s“, „%3$s“, „%4$s“, „%5$s“ või „%6$s“. Seetõttu võib asjatult levida viitamisega seotud teave. Lisateavet palun vaata siit dokumendist: {w3c-recommendation}..",
    "- The `Strict-Transport-Security` HTTP header is not set to at least `%d` seconds (current value: `%d`). For enhanced security, it is recommended to use a long HSTS policy." : "„Strict-Transport-Security“ HTTP-päisekirje pole määratus vähemalt „%d“ sekundiks (väärtus hetkel: „%d“). Parema turvalisuse nimel soovitame, et võtad HSTS-i korrektselt kasutusele.",
    "- The `Strict-Transport-Security` HTTP header is malformed: `%s`. For enhanced security, it is recommended to enable HSTS." : "„Strict-Transport-Security“ HTTP-päisekirje on vigane: „%s“. Parema turvalisuse nimel soovitame, et võtad HSTS-i kasutusele.",
    "- The `Strict-Transport-Security` HTTP header is not set (should be at least `%d` seconds). For enhanced security, it is recommended to enable HSTS." : "„Strict-Transport-Security“ HTTP-päisekirje on määramata (selle väärtus peaks olema vähemalt „%d“ sekundit). Parema turvalisuse nimel soovitame, et võtad HSTS-i kasutusele.",
    "Some headers are not set correctly on your instance" : "Mõned serveripäringute päisekirjed pole selles serveris korrektsed",
    "Could not check that your web server serves security headers correctly. Please check manually." : "Ei õnnestunud kontrollida, kas sinu veebiserveri päringuvastustes on turvalisusega seotud päisekirjed korrektsed. Palun kontrolli seda käsitsi või muu teenusega.",
    "Could not check that your web server serves security headers correctly, unable to query `%s`" : "Ei õnnestunud kontrollida, kas sinu veebiserveri päringuvastustes on turvalisusega seotud päisekirjed korrektsed. „%s“ päringu tegemine polnud võimalik.",
    "Your server is correctly configured to send security headers." : "Sinu veebiserveri päringuvastustes on turvalisusega seotud päisekirjed korrektsed.",
    "Configuration server ID" : "Seadista serveri tunnus (server ID)",
    "Server identifier isn’t configured. It is recommended if your Nextcloud instance is running on several PHP servers. Add a server ID in your configuration." : "Serveritunnus pole seadistatud. Kui sinu Nextcloudi server kasutab mitut PHP-serverit, siis on selle lisamine soovitatav. Lisa serveri tunnus oma Nextcloudi seadistustesse.",
    "\"%d\" is not a valid server identifier. It must be between 0 and 1023." : "„%d“ pole korrektne serveritunnus. Väärtus peab jääma 0 ja 1023 vahele.",
    "Server identifier is configured and valid." : "Serveritunnus on seadistatud ning kehtiv.",
    "Database version" : "Andmebaasi versioon",
    "MariaDB version 10.3 detected, this version is end-of-life and only supported as part of Ubuntu 20.04. MariaDB >=%1$s and <=%2$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Tuvastasin MariaDB versiooni 10.3 ning tema kasutusperiood on lõppenud ja tugi on olemas vaid Ubuntu 20.04 puhul. Parima jõudluse, stabiilsuse ja funktsionaalsuse mõttes soovitame selle Nextcloudi versiooni jaoks MariaDB versioone >=%1$s ja <= %2$s.",
    "MariaDB version \"%1$s\" detected. MariaDB >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Tuvastasin MariaDB versiooni „%1$s“. Parima jõudluse, stabiilsuse ja funktsionaalsuse mõttes soovitame selle Nextcloudi versiooni jaoks MariaDB versioone >=%2$s ja <= %3$s.",
    "MySQL version \"%1$s\" detected. MySQL >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Tuvastasin MySQLi versiooni „%1$s“. Parima jõudluse, stabiilsuse ja funktsionaalsuse mõttes soovitame selle Nextcloudi versiooni jaoks  MySQLi versioone >=%2$s ja <= %3$s.",
    "PostgreSQL version \"%1$s\" detected. PostgreSQL >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Tuvastasin PostgreSQLi versiooni „%1$s“. Parima jõudluse, stabiilsuse ja funktsionaalsuse mõttes soovitame selle Nextcloudi versiooni jaoks  PostgreSQLi >=%2$s ja <= %3$s.",
    "Nextcloud %d does not support your current version, so be sure to update the database before updating your Nextcloud Server." : "Nextcloud %d ei toeta sinu praegust versiooni, seega enne Nextcloudi versiooniuuendust uuenda kasutatav andmebaasimootori versioon.",
    "Oracle version \"%1$s\" detected. Oracle >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "Tuvastasin Oracle'i versiooni „%1$s“. Selle Nextcloudi versiooni puhul on parima jõudluse, stabiilsuse ja funktsionaalsuse mõttes soovitatav Oracle serveri versioon >=%2$s ja <=%3$s.",
    "Unknown database platform" : "Tuvastamatu andmebaasiplatvorm",
    "Architecture" : "Arhitektuur",
    "64-bit" : "64-bitine",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit!" : "Tundub, et kasutad PHP 32-bitist versiooni. Tõhusaks toimimiseks eeldab Nextcloud 64-bitist keskkonda. Palun uuenda oma serveri operatsioonisüsteem ja PHP 64-bitiseks versiooniks!",
    "Task Processing pickup speed" : "Ülesannete töötlemise kiirus",
    "_No scheduled tasks in the last day._::_No scheduled tasks in the last %n days._" : ["Viimase päeva jooksul pole käivitatud ühtegi ajastatud käsku.","Viimase %n päeva jooksul pole käivitatud ühtegi ajastatud käsku."],
    "_The task pickup speed has been ok in the last day._::_The task pickup speed has been ok in the last %n days._" : ["Käskude käivitamise kiirus on olnud viimase päeva jooksul mõistlik.","Käskude käivitamise kiirus on olnud viimase %n päeva jooksul mõistlik."],
    "_The task pickup speed has been slow in the last day. Many tasks took longer than 4 minutes to be picked up. Consider setting up a worker to process tasks in the background._::_The task pickup speed has been slow in the last %n days. Many tasks took longer than 4 minutes to be picked up. Consider setting up a worker to process tasks in the background._" : ["Käskude käivitamise kiirus on olnud viimase päeva jooksul aeglane. Mitmete käskude puhul kulus selleks enam kui 4 minutit. Kaalu selleks eraldi protsessi seadistamist, mis toimiks taustal.","Käskude käivitamise kiirus on olnud viimase %n päeva jooksul aeglane. Mitmete käskude puhul kulus selleks enam kui 4 minutit. Kaalu selleks eraldi protsessi seadistamist, mis toimiks taustal."],
    "_Most tasks were successful in the last day._::_Most tasks were successful in the last %n days._" : ["Enamuse käskude käivitamine viimase päeva jooksul õnnestus.","Enamuse käskude käivitamine viimase %n päeva jooksul õnnestus."],
    "_A lot of tasks failed in the last day. Consider checking the nextcloud log for errors and investigating whether the AI provider apps have been set up correctly._::_A lot of tasks failed in the last %n days. Consider checking the nextcloud log for errors and investigating whether the AI provider apps have been set up correctly._" : ["Paljude käskude käivitamine viimase päeva jooksul ei õnnestunud. Vigade tuvastamiseks palun vaata Nextcloudi logidesse ja kontrolli, kas tehisaru teenusepakkujad on korrektselt seadistatud.","Paljude käskude käivitamine viimase %n päeva jooksul ei õnnestunud. Vigade tuvastamiseks palun vaata Nextcloudi logidesse ja kontrolli, kas tehisaru teenusepakkujad on korrektselt seadistatud."],
    "The PHP function \"disk_free_space\" is disabled, which prevents the check for enough space in the temporary directories." : "PHP funktsioon „disk_free_space“ pole kasutusel. Selle puudumine takistab ajutiste kaustade jaoks vajaliku andmeruumi kontrollimist.",
    "- %.1f GiB available in %s (PHP temporary directory)" : "- %.1f GiB on saadaval kaustas „%s“ (PHP ajutine kaust)",
    "- %.1f GiB available in %s (Nextcloud temporary directory)" : "- %.1f GiB on saadaval kaustas „%s“ (Nextcloudi ajutine kaust)",
    "Temporary directory is correctly configured:\n%s" : "Ajutine kaust on seadistatud korrektselt:\n%s",
    "Second factor configuration" : "Kaheastmelise autentimise seadistus",
    "This instance has no second factor provider available." : "Selles serveris pole kaheastmelise autentimise teenusepakkujaid saadaval.",
    "Second factor providers are available but two-factor authentication is not enforced." : "Kaheastmelise autentimise teenusepakkujad on saadaval, kuid nende kasutamine pole kohustuslik.",
    "Second factor providers are available and enforced: %s." : "Kaheastmelise autentimise teenusepakkujad on saadaval ning nende kasutamine on kohustuslik: %s.",
    ".well-known URLs" : "„.well-known“ võrguaadressid",
    "`check_for_working_wellknown_setup` is set to false in your configuration, so this check was skipped." : "Kuna „check_for_working_wellknown_setup“ seadistus on selle serveri seadistustes olekus „false“, siis on vastav kontroll jäänud vahele.",
    "Could not check that your web server serves `.well-known` correctly. Please check manually." : "Ei õnnestunud kontrollida, kas sinu veebiserver edastab „.well-known“ võrguaadresse korrektselt. Palun kontrolli seda käsitsi või muu teenusega.",
    "Your web server is not properly set up to resolve `.well-known` URLs, failed on:\n`%s`" : "Sinu veebiserver ei edasta „.well-known“ võrguaadresse korrektselt, viga tekkis siin:\n„%s“",
    "Your server is correctly configured to serve `.well-known` URLs." : "Sinu veebiserver edastab „.well-known“ võrguaadresse korrektselt.",
    "Font file loading" : "Kirjatüübi fail on laadimas",
    "Could not check for {extension} loading support. Please check manually if your webserver serves `.{extension}` files." : "Ei õnnestunud kontrollida, kas „{extension}“-failide tugi toimib. Palun kontrolli käsitsi, kas sinu veebiserver suudab edastada „{extension}“ faile.",
    "Profile information" : "Kasutajaprofiili teave",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profiilipilt, täisnimi, e-posti aadress, telefoninumber, aadress, veebisait, Twitteri konto, organisatsioon, roll, alapealkiri, elulugu ja asjaolu, kas sinu profiil on kasutusel.",
    "Nextcloud settings" : "Nextcloudi seadistused",
    "Allow AI usage for guest users" : "Luba külaliskasutajatel kasutada tehiasru",
    "Provider for Task types" : "Teenusepakkuja konkreetsete ülesannete tüüpide jaoks",
    "Enable" : "Lülita sisse",
    "Machine translation" : "Masintõlge",
    "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Masintõlketeenust saavad pakkuda erinevad rakendused. Siinkohal saad määratleda hetkel paigaldatud tõlkerakenduste prioriteedi.",
    "Image generation" : "Pildiloome",
    "Text processing" : "Tekstitöötlus",
    "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Tekstitöötluse teenust saavad pakkuda erinevad rakendused. Siinkohal saad määratleda erinevate ülesannete jaoks mõeldud rakendusi.",
    "Task:" : "Ülesanded:",
    "Here you can decide which group can access certain sections of the administration settings." : "Siinkohal saad sa otsustada mis gruppidel on ligipääs valitud haldusseadistustele.",
    "Unable to modify setting" : "Seadistuse muutmine ei õnnestu",
    "None" : "Pole",
    "Changed disclaimer text" : "Vastutusest lahtiütluse tekst on muutunud",
    "Deleted disclaimer text" : "Vastutusest lahtiütluse tekst on kustutatud",
    "Could not set disclaimer text" : "Vastutusest lahtiütluse teksti seadistamine ei õnnestunud",
    "Allow apps to use the Share API" : "Luba rakendustel kasutada Share API-t",
    "Allow resharing" : "Luba edasijagamine",
    "Allow sharing with groups" : "Luba gruppidega jagamine",
    "Restrict users to only share with users in their groups" : "Luba kasutajatel jagada kasutajatega ainult oma grupi piires",
    "Ignore the following groups when checking group membership" : "Gruppide liikmelisuse kontrollimisel eira järgnevaid gruppe",
    "Allow users to preview files even if download is disabled" : "Luba kasutajatel vaadata failide eelvaateid ka siis, kui allalaadimine on keelatud",
    "Users will still be able to screenshot or record the screen. This does not provide any definitive protection." : "See ei taga lõplikku kaitset - kasutajatel on ikkagi võimalus teha ekraanitõmmiseid või -salvestusi.",
    "Allow users to share via link and emails" : "Luba kasutajatel lingiga ja e-postiga jagamist",
    "Allow public uploads" : "Luba avalikud üleslaadimised",
    "Allow public shares to be added to other clouds by federation." : "Luba avalikku jaosmeediat lisada serveritesse liitpilves.",
    "This will add share permissions to all newly created link shares." : "Sellega lisatakse vastavad õigused kõigile uutele loodavatale lingiga jagamistele.",
    "Always ask for a password" : "Alati küsi salasõna",
    "Enforce password protection" : "Jõusta salasõnakaitse",
    "Exclude groups from password requirements" : "Välista grupid salasõnareeglitest",
    "Exclude groups from creating link shares" : "Välista grupid jagamislinkide loomisest",
    "Allow users to set custom share link tokens" : "Luba kasutajatel jagamislinkidele määrata tunnuslube",
    "Shares with guessable tokens may be accessed easily" : "Ligipääs ennustatava tunnusloaga jaosmeediale on väga lihtne",
    "Limit sharing based on groups" : "Piira jagamist gruppide alusel",
    "Allow sharing for everyone (default)" : "Luba jagamine kõikidele (vaikimisi)",
    "Exclude some groups" : "Välista mõned grupid",
    "Allow some groups" : "Luba mõned grupid",
    "Groups allowed to share" : "Grupid, millel on jagamine lubatud",
    "Groups excluded from sharing" : "Jagamisest välistatud grupid",
    "Not allowed groups will still be able to receive shares, but not to initiate them." : "Mittelubatud gruppide liikmed saavad vastu võtta jagamisi, kuid ise jagamisi algatada ei saa.",
    "Set default expiration date for internal shares" : "Jagamisel selle serveri piires kasuta vaikimisi aegumist",
    "Enforce expiration date" : "Sunnitud aegumise kuupäev",
    "Default expiration time of new shares in days" : "Uue jaosmeedia vaikimisi aegumine päevades",
    "Expire shares after x days" : "Jaosmeedia aegub x päeva möödudes",
    "Set default expiration date for shares to other servers" : "Jagamisel teistesse serveritesse kasuta vaikimisi aegumist",
    "Enforce expiration date for remote shares" : "Määra lingi kaugserverid asuva jaosmeedia vaikimisi aegumiskuupäev ",
    "Default expiration time of remote shares in days" : "Kaugserveris asuva jaosmeedia vaikimisi aegumine päevades",
    "Expire remote shares after x days" : "Jaosmeedia aegub x päeva möödudes",
    "Set default expiration date for shares via link or mail" : "Määra lingi või e-kirjaga jagatava jaosmeedia vaikimisi aegumiskuupäev",
    "Enforce expiration date for link or mail shares" : "Jõusta lingiga või e-postiga jagamise aegumiskuupäev",
    "Default expiration time of shares in days" : "Jaosmeedia vaikimisi aegumine päevades",
    "Privacy settings for sharing" : "Jagamise privaatsusseadistused",
    "Sharing autocompletion restrictions" : "Automaattäitmise piirangute jagamine",
    "Also allow autocompletion on full match of the user ID" : "Lisaks luba automaatset täitmist kasutajatunnuse täisvaste puhul",
    "Also allow autocompletion on full match of the display name" : "Lisaks luba automaatset täitmist kuvatava nime täisvaste puhul",
    "Also allow autocompletion on full match of the user email" : "Lisaks luba automaatset täitmist e-posti aadressi täisvaste puhul",
    "Do not use second user displayname for full match" : "Ära pruugi kasutaja teist kuvatavat nime täisvaste otsimiseks",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Kuva avaliku lingiga üleslaadimise lehel lahtiütluste tekst (vaid siis, kui failide loend on peidetud)",
    "Disclaimer text" : "Vastutusest lahtiütluse tekst",
    "This text will be shown on the public link upload page when the file list is hidden." : "Seda teksti näidatakse avaliku lingiga üleslaadimise lehel kui failide loend on peidetud.",
    "Default share permissions" : "Vaikimisi õigusel jagamisel",
    "Two-Factor Authentication" : "Kaheastmeline autentimine",
    "Two-factor authentication can be enforced for all accounts and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Kaheastmelist autentimist on võimalik teha kohustuslikuks kas kõikidele kasutajakontodele või konkreetsete gruppide kaupa. Kui kaheastmelise autentimise kohustuslikkus on määratud, kuid on kasutajal seadistamata, siis ta ei saa siia serverisse sisse logida.",
    "Enforce two-factor authentication" : "Tee kaheastmeline autentimine kohustuslikuks",
    "Limit to groups" : "Luba gruppidele",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Kaheastmelise autentimise kohustuslikkust saad määrata ka konkreetsete gruppide kaupa.",
    "Two-factor authentication is enforced for all members of the following groups." : "Kaheastmeline autentimine on kohustuslik nende gruppide kõikidele liikmetele.",
    "Enforced groups" : "Kohustuslik neis gruppides",
    "Two-factor authentication is not enforced for members of the following groups." : "Kaheastmeline autentimine pole kohustuslik nende gruppide liikmetele.",
    "Excluded groups" : "Välistatud neis gruppides",
    "Save changes" : "Salvesta muudatused",
    "Choose Deploy Daemon for {appName}" : "Vali {appName} rakenduse jaoks kasutuselevõtmise taustateenus",
    "Default" : "Vaikimisi",
    "Registered Deploy daemons list" : "Registreeritud kasutuselevõtmise taustateenuste loend",
    "No Deploy daemons configured" : "Ühtegi kasutuselevõtmise taustateenust pole seadistatud",
    "Register a custom one or setup from available templates" : "Registreeri enda eelistus või vali olemasolevate mallide seast",
    "Manage Deploy daemons" : "Halda kasutuselevõtmise taustateenuseid",
    "Show details for {appName} app" : "Näita „{appName}“ rakenduse üksikasju",
    "Update to {update}" : "Uuenda versioonini {update}",
    "Remove" : "Eemalda",
    "Featured" : "Esiletõstetud",
    "This app is supported via your current Nextcloud subscription." : "See rakendus on toetatud sinu praeguses Nextcloudi tellimuses. ",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Esiletõstetud rakendusi arendatakse kogukonna poolt. Nad pakuvad võimalust kasutada olulist funktsionaalsust ning on sobilikud igapäevaseks kasutuseks.",
    "Community rating: {score}/5" : "Kogukonna hinnang: {score}/5",
    "Office suite switching is managed through the Nextcloud All-in-One interface." : "Kontoritarkvarapakettide vahetamine toimub Nextcloudi kõik-ühes (All-in-One) kasutajaliidesest.",
    "Please use the AIO interface to switch between office suites." : "Paluna kasuta kontoritarkvarapakettide vahetamiseks Nextcloudi kõik-ühes (All-in-One) kasutajaliidesest.",
    "Select your preferred office suite. Please note that installing requires manual server setup." : "Vali eelistatud kontoritarkvarapakett. Palun arvesta, et paigaldamine eeldab ka serveri käsitsi seadistamist.",
    "installed" : "paigaldatud",
    "Learn more" : "Lisateave",
    "Disable office suites" : "Lülita kontoritarkvarapaketid välja",
    "Disable all" : "Lülita kõik välja",
    "Download and enable all" : "Laadi kõik alla ja võta kasutusele",
    "All office suites disabled" : "Kõik kontoritarkvarapaketid on lülitatud välja",
    "{name} enabled" : "{name} on kasutusel",
    "All apps are up-to-date." : "Kõik rakendused on uuendatud",
    "Icon" : "Ikoon",
    "Name" : "Nimi",
    "Version" : "Versioon",
    "Level" : "Tase",
    "Actions" : "Tegevused",
    "Results from other categories" : "Tulemused muudest kategooriatest",
    "No apps found for your version" : "Sinu versiooni jaoks ei leitud ühtegi rakendust",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n rakenduse jaoks leidub uuendusi","%n rakenduse jaoks leidub uuendusi"],
    "_Update_::_Update all_" : ["Uuenda","Uuenda kõik"],
    "Failed to load groups" : "Gruppe ei õnnestunud laadida",
    "Failed to create group" : "Grupi loomine ei õnnestunud",
    "Groups" : "Grupid",
    "Creating group…" : "Loon gruppi…",
    "Create group" : "Loo grupp",
    "Group name" : "Grupi nimi",
    "Please enter a valid group name" : "Palun sisesta korrektne grupi nimi",
    "Search groups…" : "Otsi gruppe…",
    "List of groups. This list is not fully populated for performance reasons. The groups will be loaded as you navigate or search through the list." : "Gruppide loend. Jõudluse mõttes ei ole kogu loend esimesel hetkel tervikuna nähtav. Uued grupid lisanduvad sedamööda, kui sa loendis edasi liigud.",
    "Loading groups…" : "Laadin gruppe…",
    "Could not load app discover section" : "Rakenduse tuvastamise jaotise laadimine ei õnnestunud",
    "Could not render element" : "Elemendi töötlemine ei õnnestunud",
    "Nothing to show" : "Pole midagi näidata",
    "Could not load section content from app store." : "Jaotise sisu laadimine rakendustepoest ei õnnestunud.",
    "Loading" : "Laadin",
    "Fetching the latest news…" : "Laadin viimaseid uuendusi",
    "Carousel" : "Karussell",
    "Previous slide" : "Eelmine slaid",
    "Next slide" : "Järgmine slaid",
    "Choose slide to display" : "Vali kuvatav slaid",
    "{index} of {total}" : "{index} / {total}",
    "Daemon" : "Taustateenus",
    "Deploy Daemon" : "Kasutuselevõtmise taustateenus",
    "Type" : "Tüüp",
    "Display Name" : "Kuvatav nimi",
    "GPUs support" : "Graafikaprotsessori tugi",
    "Compute device" : "Arvutusseade",
    "Advanced deploy options" : "Kasutuselevõtmise lisavalikud",
    "Edit ExApp deploy options before installation" : "Muuda ExApp konteineri seadistuse enne paigaldamist",
    "Configured ExApp deploy options. Can be set only during installation" : "ExApp'i konteineri seadistuse valikud. Neid saab määrata vaid paigalduse ajal",
    "Environment variables" : "Keskonnamuutujad",
    "ExApp container environment variables" : "ExApp konteineri keskonnamuutujad",
    "No environment variables defined" : "Ühtegi keskonnamuutujat pole defineeritud",
    "Mounts" : "Haakepunktid",
    "Define host folder mounts to bind to the ExApp container" : "Sidumaks ExApp'i konteineriga määratle peremeeskaustade haakepunktid",
    "Must exist on the Deploy daemon host prior to installing the ExApp" : "Enne ExAppi paigaldamist peab ta olema leitav kasutuselevõtmise taustateenuses",
    "Host path" : "Peremeeskausta asukoht",
    "Container path" : "Konteineri asukoht",
    "Read-only" : "Ainult lugemiseks",
    "Remove mount" : "Eemalda haakepunkt",
    "New mount" : "Uus haakepunkt",
    "Enter path to host folder" : "Sisesta peremeeskausta asukoht",
    "Enter path to container folder" : "Sisesta konteinerikausta asukoht",
    "Toggle read-only mode" : "Lülita „ainult lugemiseks“ režiim sisse/välja",
    "Confirm adding new mount" : "Kinnita uue haakepunkti lisamine",
    "Confirm" : "Kinnita",
    "Cancel adding mount" : "Katkesta haakepunkti lisamine",
    "Cancel" : "Loobu",
    "Add mount" : "Lisa haakepunkt",
    "ExApp container mounts" : "ExApp konteinerite haakepunktid",
    "No mounts defined" : "Ühtegi haakepunkti pole määratletud",
    "Description" : "Kirjeldus",
    "View in store" : "Vaata poes",
    "Visit website" : "Külasta veebisaiti",
    "Usage documentation" : "Kasutusjuhend",
    "Admin documentation" : "Dokumentatsioon peakasutajale",
    "Developer documentation" : "Arendaja dokumentatsioon",
    "Details" : "Üksikasjad",
    "All" : "Kõik",
    "Limit app usage to groups" : "Piira rakenduse kasutamist gruppidega",
    "No results" : "Vasteid ei leitud",
    "Update to {version}" : "Uuenda versioonile {version}",
    "Deploy options" : "Kasutuselevõtmise valikud",
    "Default Deploy daemon is not accessible" : "Kasutuselevõtmise taustateenus pole leitav",
    "Delete data on remove" : "Eemaldamisel kustuta andmed",
    "This app has no minimum {productName} version assigned. This will be an error in the future." : "Sellel rakendusel pole määratud minimaalset {productName}i versiooni. See põhjustab tulevikus veateateid.",
    "This app has no maximum {productName} version assigned. This will be an error in the future." : "Sellel rakendusel pole määratud maksimaalset {productName}i versiooni. See põhjustab tulevikus veateateid.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Seda rakendust ei saa paigaldada, sest järgmised sõltuvusel ei ole täidetud:",
    "Latest updated" : "Viimati uuendatud",
    "Author" : "Autor",
    "Categories" : "Kategooriad",
    "Resources" : "Ressursid",
    "Documentation" : "Dokumentatsioon",
    "Interact" : "Suhtle meiega",
    "Report a bug" : "Teata veast",
    "Request feature" : "Palu arendajatelt funktsionaalsuse lisamist",
    "Ask questions or discuss" : "Küsi nõu või aruta",
    "Rate the app" : "Hinda rakendust",
    "Rate" : "Hinda",
    "Changelog" : "Muudatuste logi",
    "Google Chrome for Android" : "Google Chrome for Android",
    "{productName} iOS app" : "{productName}i iOS-i rakendus",
    "{productName} Android app" : "{productName}i Androidi rakendus",
    "{productName} Talk for iOS" : "{productName} Talk iOS-i jaoks",
    "{productName} Talk for Android" : "{productName} Talk Androidi jaoks",
    "Sync client" : "Sünkroonimisklient",
    "This session" : "See sessioon",
    "{client} - {version} ({system})" : "{client} - {version} ({system})",
    "{client} - {version}" : "{client} - {version}",
    "Device name" : "Seadme nimi",
    "Cancel renaming" : "Katkesta nime muutmine",
    "Save new name" : "Salvesta uus nimi",
    "Marked for remote wipe" : "Märgitud kaugkustutamiseks",
    "Device settings" : "Seadme seadistused",
    "Allow filesystem access" : "Luba juurdepääs failisüsteemile",
    "Rename" : "Muuda nime",
    "Revoke" : "Tühista",
    "Wipe device" : "Kaugkustuta seade",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Selle tunnusloa tühistamine võib katkestada sinu seadme kaugkustutamise, kui kustutamine pole veel alanud.",
    "Device" : "Seade",
    "Last activity" : "Viimane tegevus",
    "Devices & sessions" : "Seadmed & sessioonid",
    "Web, desktop and mobile clients currently logged in to your account." : "Sinu kontole hetkel sisse loginud veebi-, töölaua-, ja mobiilsed kliendid.",
    "Error while creating device token" : "Tõrge seadme märke loomisel",
    "App name" : "Rakenduse nimi",
    "Create new app password" : "Loo uus rakenduse salasõna",
    "App password copied!" : "Rakenduse salasõna on kopeeritud!",
    "Copy app password" : "Kopeeri rakenduse salasõna",
    "Login name copied!" : "Kasutajanimi on kopeeritud!",
    "Copy login name" : "Kopeeri kasutajanimi",
    "Could not copy app password. Please copy it manually." : "Ei õnnestunud kopeerida rakenduse salasõna. Palun tee seda käsitsi.",
    "Could not copy login name. Please copy it manually." : "Ei õnnestunud kopeerida kasutajanime. Palun tee seda käsitsi.",
    "New app password" : "Uus rakenduse salasõna",
    "Use the credentials below to configure your app or device. For security reasons this password will only be shown once." : "Kasuta alljärgnevat autentimisvõimalust oma rakenduse või seadme seadistamiseks. Turvapõhjustel näitame me seda salasõna vaid üks kord.",
    "Login" : "Kasutajanimi",
    "Password" : "Salasõna",
    "Show QR code for mobile apps" : "Näita QR-koodi nutiseadmete rakenduste jaoks",
    "Use system cron service to call the cron.php file every 5 minutes." : "Kasuta süsteemi cron-teenust, et käivitada cron.php faili iga 5 minuti järel.",
    "The cron.php needs to be executed by the system account \"{user}\"." : "cron.php peab olema käivitatud süsteemikasutaja „{user}“ poolt.",
    "Last job execution ran {time}. Something seems wrong." : "Viimane käivitus kestis {time}. See pole päris õige.",
    "Last job ran {relativeTime}." : "Viimane käivitus kestis {relativeTime}.",
    "Background job did not run yet!" : "Taustal töötav ülesanne pole veel käivitunud!",
    "AJAX" : "AJAX",
    "Execute one task with each page loaded. Use case: Single account instance." : "Käivita igal lehe laadimisel üks ülesanne. Kasutusjuhtum: ühe kasutajakontoga server.",
    "Webcron" : "Webcron",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 accounts depending on the usage)." : "cron.php on registreeritud webcroni teenuses käivitama cron.php skripti HTTP-päringuga iga 5 minuti järel. Kasutusjuhtum: väga väike server (sõltuvalt kasutusviisist 1–5 kontot).",
    "Cron (Recommended)" : "Cron (Soovitatav)",
    "Unable to update profile default setting" : "Profiili vaikimisi seadistuste uuendamine ei õnnestu",
    "Profile" : "Profiil",
    "Enable or disable profile by default for new accounts." : "Lülita profiil uute kasutajate jaoks sisse või välja.",
    "Password confirmation is required" : "Salasõna kinnitamine on vajalik",
    "Failed to save setting" : "Seadistuse salvestamine ei õnnestunud",
    "{app}'s declarative setting field: {name}" : "„{app}“ rakenduse deklaratiivse seadistuse väli: „{name}“",
    "Unable to update server side encryption config" : "Serveripoolse krüptimise seadistusi ei õnnestu uuendada",
    "Server-side encryption" : "Serveripoolne krüptimine",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Serveripoole krüptimine võimaldab serverisse üleslaaditud faile krüptida. Sellega kaasnevad piirangud, näiteks jõudluskadu. Lülita see sisse ainult siis, kui vaja on.",
    "To encrypt all existing files run this OCC command:" : "Kõikide failide krüptimiseks käivita käsurealt see OCC-käsk:",
    "Enable server-side encryption" : "Võta serveripoolne krüptimine kasutusele",
    "Disabling server side encryption is only possible using OCC, please refer to the documentation." : "Serveripoolse krüptimise väljalülitamine on võimalik vaid käsureapõhise OCC-tarvikuga. Lisateavet leiad dokumentatsioonist.",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Krüptimise moodul pole laaditud, palun luba krüptimise moodul rakenduste menüüs.",
    "Select default encryption module:" : "Määra vaikimisi krüptimise moodul:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Sa pead oma krüptovõtmed kolima vanast vormingust (ownCloud <= 8.0) uude. Palun lülita „Vakimise krüptimise moodul“ sisse ja käivita „{command}“",
    "Cancel encryption" : "Katkesta krüptimine",
    "Enable encryption" : "Luba krüptimine",
    "Confirm enabling encryption" : "Kinnita krüptimise kasutuselevõtmine",
    "Please read carefully before activating server-side encryption:" : "Palun loe hoolikalt enne serveripoolse krüptimise kasutuselevõtmist:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Kui krüptimine on kasutusel, siis kõik sellest hetkest alates serverisse üleslaaditavad saavad olema serveris krüptitud kujul. Tulevikus on võimalik krüptimist välja lülitada vaid siis, kui kasutusel olev krüptimise lisamoodul seda võimaldab ja eeltingimused (nt taastevõtme olemasolu) on täidetud.",
    "By default a master key for the whole instance will be generated. Please check if that level of access is compliant with your needs." : "Vaikimisi luuakse üldvõti kogu serveri jaoks. Palun kontrolli, kas sellest johtuvad ligipääsuõigused vastavad sinu vajadustele.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Ainult krüptimine ei taga süsteemi turvalisust. Saamaks teada kuidas krüptimise rakendus töötab ja mis kasutusjuhtumiteks ta on mõeldud, palun vaata dokumentatsiooni.",
    "Be aware that encryption always increases the file size." : "Pane tähele, et krüptimine suurendab alati failide suurust.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Alati on hea mõte, kui varundad oma andmeid. Kui aga kasutusel on krüptimine, siis palun kontrolli, et lisaks andmetele on varundatud ka krüptovõtmed.",
    "Refer to the admin documentation on how to manually also encrypt existing files." : "Süsteemihalduse juhendist leiad teavet kuidas saad käsitsi krüptida juba olemasolevaid faile.",
    "This is the final warning: Do you really want to enable encryption?" : "See on viimane hoiatus: Kas oled kindel, et soovid krüptimise sisse lülitada?",
    "Failed to delete group \"{group}\"" : "„{group}“ grupi eemaldamine ei õnnestunud",
    "Please confirm the group removal" : "Palun kinnita grupi eemaldamine",
    "You are about to delete the group \"{group}\". The accounts will NOT be deleted." : "Sa oled eemaldamas gruppi „{group}“. Selles grupis olevad kasutajad aga JÄÄVAD kustutamata.",
    "Submit" : "Saada",
    "Rename group" : "Muuda grupi nime",
    "Delete group" : "Kustuta grupp",
    "Current password" : "Praegune salasõna",
    "New password" : "Uus salasõna",
    "Change password" : "Muuda salasõna",
    "Choose your profile picture" : "Vali oma tunnuspilt",
    "Please select a valid png or jpg file" : "Palun vali korrektne png või jpg fail",
    "Error setting profile picture" : "Viga tunnuspildi jõustamisel",
    "Error cropping profile picture" : "Viga tunnuspildi kadreerimisel",
    "Error saving profile picture" : "Viga tunnuspildi salvestamisel",
    "Error removing profile picture" : "Viga tunnuspildi eemaldamisel",
    "Your profile picture" : "Sinu tunnuspilt",
    "Upload profile picture" : "Laadi tunnuspilt üles",
    "Choose profile picture from Files" : "Vali oma tunnuspilt failirakendusest",
    "Remove profile picture" : "Eemalda tunnuspilt",
    "The file must be a PNG or JPG" : "Fail peab olema png või jpg vormingus",
    "Picture provided by original account" : "Pilt esitatud originaalse konto poolt",
    "Set as profile picture" : "Määra tunnuspildiks",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Palun arvesta, et võib kuluda kuni 24 tundi enne, kuni sinu uus tunnuspilt on kõikjal uuendatud.",
    "Your biography. Markdown is supported." : "Teave sinu kohta. Võid kasutada ka markdown-vormingut.",
    "Unable to update date of birth" : "Sünnikuupäeva seadistamine ei õnnestu",
    "Enter your date of birth" : "Palun sisesta sünnikuupäev",
    "Bluesky handle" : "Kasutajanimi Bluesky's",
    "You are using {s}{usage}{/s}" : "Sa kasutad: {s}{usage}{/s}",
    "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Sa kasutad: {s}{usage}{/s} / {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
    "You are a member of the following groups:" : "Sa oled nende gruppide liige:",
    "Your full name" : "Sinu täispikk nimi",
    "Unable to update primary email address" : "Ei õnnestunud uuendada põhilist e-postiaadressi",
    "Unable to delete additional email address" : "Ei õnnestunud kustutada täiendavat e-posti aadressi",
    "No email address set" : "E-posti aadressi pole veel määratud",
    "Email options" : "E-posti valikud",
    "Options for additional email address {index}" : "Täiendava e-posti aadressi valikud: {index}",
    "Remove primary email" : "Eemalda põhiline e-postiaadress",
    "Delete email" : "Kustuta e-posti aadress",
    "This address is not confirmed" : "See aadress pole kinnitatud",
    "Unset as primary email" : "Eemalda määramine põhiliseks e-postiaadressiks",
    "Set as primary email" : "Määra põhiliseks e-postiaadressiks",
    "Additional email address {index}" : "Täiendav e-posti aadress {index}",
    "Unable to delete primary email address" : "Ei õnnestunud eemaldada põhilist e-postiaadressi",
    "Unable to add additional email address" : "Ei õnnestunud laadida täiendavat e-posti aadressi",
    "Unable to update additional email address" : "Ei õnnestunud uuendada täiendavat e-posti aadressi",
    "Primary email for password reset and notifications" : "Põhiline e-postiaadress salasõna lähtestamiseks ja teavituste jaoks",
    "Your handle" : "Sinu kasutajanimi",
    "Derived from your locale ({weekDayName})" : "Tuletatud lokaadist ({weekDayName})",
    "Unable to update first day of week" : "Nädala esimese päeva uuendamine ei õnnestu",
    "Day to use as the first day of week" : "Nädala esimene päev",
    "Your headline" : "Sind kirjeldav alapealkiri",
    "No language set" : "Keel on määramata",
    "Unable to update language" : "Keele uuendamine ei õnnestu",
    "Languages" : "Keeled",
    "Help translate" : "Aita tõlkida",
    "No locale set" : "Lokaat on määramata",
    "Unable to update locale" : "Lokaadi uuendamine ei õnnestu",
    "Locales" : "Lokaadid",
    "Week starts on {firstDayOfWeek}" : "Nädala esimene päev: {firstDayOfWeek}",
    "Your city" : "Sinu asukoht",
    "Your organisation" : "Sinu organisatsioon",
    "Your phone number" : "Sinu telefoninumber",
    "Edit your Profile visibility" : "Muuda oma profiili nähtavust",
    "Unable to update profile enabled state" : "Profiili kasutuseloleku uuendamine ei õnnestu",
    "Enable profile" : "Võta profiil kasutusele",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Sinu profiili nähtavuse ja toimeala puhul arvestatakse rangemat  tingimust. Kui näiteks nähtavus on „Näita kõigile“ ja toimeala on „Privaatne“, siis kasutusele jääb „Privaatne“.",
    "Unable to update visibility of {displayId}" : "„{displayId}“ nähtavust polnud võimalik uuendada",
    "she/her" : "she/her",
    "he/him" : "he/him",
    "they/them" : "they/them",
    "Your pronouns. E.g. {pronounsExample}" : "Sinu asesõnad, näiteks „{pronounsExample}“",
    "Your role" : "Sinu roll",
    "Timezone" : "Ajavöönd",
    "Your X (formerly Twitter) handle" : "Sinu X-i (varasemalt Twitteri) kasutajanimi",
    "Your website" : "Sinu veebileht",
    "Invalid value" : "Vigane väärtus",
    "Unable to update {property}" : "„{property}“ uuendamine ei õnnestu",
    "No {property} set" : "„{property}“ on määramata",
    "Change scope level of {property}, current scope is {scope}" : "Muuda „{property}“ toimeala, hetkel kehtib „{scope}“",
    "Unable to update federation scope of the primary {property}" : "Primaarse „{property}“ uuendamine födereeritud toimealas ei õnnestu",
    "Unable to update federation scope of additional {property}" : "Täiendava „{property}“ uuendamine födereeritud toimealas ei õnnestu",
    "Add additional email" : "Lisa täiendav e-posti aadress",
    "Add" : "Lisa",
    "Create" : "Koosta",
    "Change" : "Muuda",
    "Delete" : "Kustuta",
    "Reshare" : "Jaga edasi",
    "Default config values" : "Seadistuste vaikimisi väärtused",
    "Applications config" : "Rakenduste seadistused",
    "User config" : "Kasutajate seadistused",
    "Bundled applications" : "Grupeeritud rakendused",
    "Enabled applications" : "Kasutusel rakendused",
    "Disabled applications" : "Väljalülitatud rakendused",
    "Large organization" : "Väga suur organisatsioon",
    "Big organization" : "Suur organisatsioon",
    "Small organization" : "Väike organisatsioon",
    "Hosting company" : "Serverimajutuse teenusepakkuja",
    "University" : "Ülikool",
    "School" : "Kool",
    "Club or association" : "Klubi või seltsing",
    "Family" : "Perekond",
    "Personal use" : "Isiklik kasutus",
    "Setup errors" : "Seadistusevead",
    "Setup warnings" : "Hoiatused seadistuste kohta",
    "Setup recommendations" : "Soovitused seadistamiseks",
    "Default language" : "Vaikekeel",
    "Common languages" : "Levinud keeled",
    "Other languages" : "Muud keeled",
    "Password change is disabled because the master key is disabled" : "Salasõna muutmine on lülitatud välja, kuna ka peremeesvõti on lülitatud välja",
    "No accounts" : "Kasutajakontosid pole",
    "Loading accounts …" : "Laadin kasutajakontosid…",
    "List of accounts. This list is not fully rendered for performance reasons. The accounts will be rendered as you navigate through the list." : "Kasutajakontode loend. Jõudluse mõttes ei ole kogu loend esimesel hetkel tervikuna nähtav. Uued kasutajakontid lisanduvad sedamööda, kui sa loendis edasi liigud.",
    "Manager" : "Haldaja",
    "Set line manager" : "Lisa vahetu ülemus",
    "Account name will be autogenerated" : "Kasutajakonto nimi luuakse automaatselt",
    "Account name (required)" : "Kasutajakonto nimi (nõutav)",
    "Failed to search groups" : "Gruppe ei õnnestunud otsida",
    "New account" : "Uus kasutajakonto",
    "Display name" : "Kuvatav nimi",
    "Either password or email is required" : "Kas salasõna või e-posti aadress on kohustuslik",
    "Password (required)" : "Salasõna (nõutav)",
    "Email (required)" : "E-posti aadress (nõutav)",
    "Email" : "E-post",
    "Member of the following groups (required)" : "Järgmiste gruppide liige (nõutav)",
    "Member of the following groups" : "Järgmiste gruppide liige",
    "Set account groups" : "Määra kasutajakonto grupid",
    "Admin of the following groups" : "Järgmiste gruppide peakasutaja",
    "Set account as admin for …" : "Määra kasutajakonto peakasutajaks siin:",
    "Quota" : "Kvoot",
    "Set account quota" : "Määra kasutajakonto kvoot",
    "Language" : "Keel",
    "Set default language" : "Määra vaikimisi keel",
    "Add new account" : "Lisa uus kasutajakonto",
    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} kasutajakonto…","{userCount} kasutajakontot…"],
    "_{userCount} account_::_{userCount} accounts_" : ["{userCount} kasutajakonto","{userCount} kasutajakontot"],
    "Total rows summary" : "Ridade koondkokkuvõte",
    "Scroll to load more rows" : "Täiendavate ridade laadimiseks keri",
    "Password or insufficient permissions message" : "Teavitus salasõna või puuduvate õiguste kohta",
    "Avatar" : "Tunnuspilt ehk avatar",
    "Account name" : "Kasutajakonto nimi",
    "Group admin for" : "Grupi peakasutaja",
    "Account backend" : "Kasutajakonto taustateenus",
    "Storage location" : "Salvestusruumi asukoht",
    "First login" : "Esimene sisselogimine",
    "Last login" : "Viimane sisselogimine",
    "Account actions" : "Kasutajakonto tegevused",
    "{size} used" : "{size} kasutatud",
    "Delete account" : "Kustuta konto",
    "Disconnect all devices and delete local data" : "Katkesta ühendused kõikide seadmetega ja kustuta kohalikud andmed",
    "Disable account" : "Lülita kasutajakonto välja",
    "Enable account" : "Lülita kasutajakonto sisse",
    "Resend welcome email" : "Saada tervituskiri uuesti",
    "In case of lost device or exiting the organization, this can remotely wipe the {productName} data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Kas seadme kadumisel või organisatsioonist lahkumisel on võimalik kaugkustutamise abil kustutada {productName}i andmed kõikidest „{userid}“ kasutaja seadmetest. Loomulikult toimib see vaid siis, kui vastav seade on ühendatud internetiga.",
    "Remote wipe of devices" : "Seadmete kaugkustutamine",
    "Wipe {userid}'s devices" : "Kaugkustuta kasutaja „{userid}“ seadmed",
    "Wiped {userid}'s devices" : "Kasutaja „{userid}“ seadmed on kaugkustutatud",
    "Failed to load groups with details" : "Gruppe koos üksikasjadega ei õnnestunud laadida",
    "Failed to load sub admin groups with details" : "Alamgruppe koos üksikasjadega ei õnnestunud laadida",
    "Failed to update line manager" : "Vahetu ülemuse uuendamine ei õnnestunud",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Kustuta „{userid}“ kasutajakonto täis mahus, sealhulgas tema isiklikud failid, rakenduste andmed ja muud.",
    "Account deletion" : "Kasutajakonto kustutamine",
    "Delete {userid}'s account" : "Kustuta kasutajakonto: „{userid}“",
    "Display name was successfully changed" : "Kuvatava nime muutmine õnnestus",
    "Password can't be empty" : "Salasõna ei saa olla tühi",
    "Password was successfully changed" : "Salasõna muutmine õnnestus",
    "Email can't be empty" : "E-posti aadress ei saa olla tühi",
    "Email was successfully changed" : "E-posti aadressi muutmine õnnestus",
    "Welcome mail sent!" : "Tervituskiri on saadetud!",
    "Loading account …" : "Laadin kasutajakontot…",
    "Change display name" : "Muuda kuvatavat nime",
    "Set new password" : "Määra uus salasõna",
    "You do not have permissions to see the details of this account" : "Sul puuduvad õigused selle kasutajakonto üksikasjade vaatamiseks",
    "Set new email address" : "Sisesta uus e-posti aadress",
    "Add account to group" : "Lisa kasutajakonto gruppi",
    "Set account as admin for" : "Määra kasutajakonto peakasutajaks siin:",
    "Select account quota" : "Määra kasutajakonto kvoot",
    "Set the language" : "Vali keel",
    "Toggle account actions menu" : "Lülita kasutajakonto tegevuste menüü sisse/välja",
    "Done" : "Valmis",
    "Edit" : "Muuda",
    "Account management settings" : "Kasutajakontode halduse seadistused",
    "Visibility" : "Nähtavus",
    "Show language" : "Näita keelt",
    "Show account backend" : "Näita kasutajakonto taustateenust",
    "Show storage path" : "Näita andmeruumi asukohta",
    "Show first login" : "Näita esimest sisselogimist",
    "Show last login" : "Näita viimast sisselogimist",
    "Sorting" : "Järjestus",
    "The system config enforces sorting the groups by name. This also disables showing the member count." : "Süsteem seadistus kasutab gruppide järjestamist nime alusel. Muu hulgas see ei võimalda liikmete arvu näitamist.",
    "Group list sorting" : "Rühmade loendi järjestus",
    "Sorting only applies to the currently loaded groups for performance reasons. Groups will be loaded as you navigate or search through the list." : "Jõudluse mõttes kehtib järjestus vaid hetkel laaditud gruppidele. Uued grupid lisanduvad sedamööda, kuidas sa loendis edasi liigud.",
    "By member count" : "Liikmete arvu alusel",
    "By name" : "Nime alusel",
    "Send email" : "Saada kiri",
    "Send welcome email to new accounts" : "Saada uutele kasutajatele tervituskiri",
    "Defaults" : "Vaikeväärtused",
    "Default quota" : "Vaikimisi mahupiir",
    "Select default quota" : "Vali vaikimisi andmemahu piir",
    "Server error while trying to complete WebAuthn device registration" : "Serveriviga WebAuthn seadme registreerimise lõpetamisel",
    "Passwordless authentication requires a secure connection." : "Salasõnata autentimine eeldab turvalise võrguühenduse kasutamist.",
    "Add WebAuthn device" : "Lisa WebAuthni kasutav seade",
    "Please authorize your WebAuthn device." : "Palun anna luba oma WebAuthn seadme kasutamiseks",
    "Adding your device …" : "Lisan sinu seadet…",
    "Unnamed device" : "Nimetu seade",
    "Passwordless Authentication" : "Salasõnata autentimine",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Seadista oma kasutajakonto jaoks salasõnata autentimine, mis põhineb FIDO2 standardil.",
    "No devices configured." : "Ühtegi seadet pole seadistatud.",
    "The following devices are configured for your account:" : "Järgmised seadmed on seadistatud kasutama sinu kontot:",
    "Your browser does not support WebAuthn." : "Sinu veebibrauseril puudub WebAuthni tugi.",
    "Email sent successfully" : "E-kirja saatmine õnnestus",
    "Failed to send email" : "E-kirja saatmine ei õnnestunud",
    "Failed to save email settings" : "E-posti seadistuste salvestamine ei õnnestunud",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "On oluline, et e-kirjade saatmise võimekus on seadistatud. Seda kasutatakse näiteks salasõnade lähtestamiseks ja teavituste saatmiseks.",
    "The server configuration is read-only so the mail settings cannot be changed using the web interface." : "Serveri seadistused on vaid lugemisolekus ja neid ei saa veebiliidesest muuta.",
    "Mail delivery is disabled by instance config \"{config}\"." : "E-kirjade edastamine on keelatud serveri seadistuse „{config}“ alusel.",
    "Send mode" : "Saatmise viis",
    "Encryption" : "Krüpteerimine",
    "Sendmail mode" : "Sendmaili režiim",
    "Disable certificate verification (insecure)" : "Lülita välja sertifikaadi kontroll (ebaturvaline)",
    "From address" : "Saatja aadress",
    "Domain" : "Domeen",
    "Server address" : "Serveri aadress",
    "Host" : "Host",
    "Port" : "Port",
    "Authentication" : "Autentimine",
    "Authentication required" : "Autentimine on vajalik",
    "Sending test email…" : "Saadan testkirja…",
    "Send test email" : "Saada testkiri",
    "Saving…" : "Salvestan...",
    "Save settings" : "Salvesta seadistused",
    "Please double check the {linkStartInstallationGuides}installation guides{linkEnd}, and check for any errors or warnings in the {linkStartLog}log{linkEnd}." : "Palun vaata uuesti {linkStartInstallationGuides}paigaldusjuhendit{linkEnd} ning kontrolli {linkStartLog}logides{linkEnd} leiduvaid vigu ja hoiatusi.",
    "Check the security of your {productName} over {linkStart}our security scan{linkEnd}." : "Testi selle {productName}i serveri turvalisust {linkStart}meie turvakontrolliga{linkEnd}.",
    "Security & setup warnings" : "Turva- ja paigalduse hoiatused",
    "It is important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Sinu serveri turvalisuse ja jõudluse jaoks on oluline, et kõik oleks korrektselt seadistatud. Sinu aitamiseks käivitame mõned automaatsed testid ja kontrollid. Lisateavet leiad viidatud juhendist.",
    "Checking your server …" : "Kontrollin sinu serverit …",
    "Failed to run setup checks" : "Seadistuste kontrollide käivitamine ei õnnestunud",
    "Try again" : "Proovi uuesti",
    "All checks passed." : "Kõik kontrollid on läbitud.",
    "There are some errors regarding your setup." : "Selles paigalduses on paar viga.",
    "There are some warnings regarding your setup." : "Selles paigalduses on paar hoiatust.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Peakasutajana saad jagamise valikuid täpselt seadistada. Lisateavet leiad dokumentatsioonist.",
    "You need to enable the File sharing App." : "Sa pead kasutusele võtma Failijagamise rakenduse.",
    "App Store" : "Rakendustepood",
    "Loading app list" : "Laadin rakenduste loendit",
    "Loading categories" : "Laadin kategooriaid",
    "Version {version}, {license}-licensed" : "Versioon {version}, avaldatud {license} litsentsi alusel",
    "Version {version}" : "Versioon {version}",
    "Failed to save selected preset." : "Valitud eelseadistuse salvestamine ei õnnestunud.",
    "Select a configuration preset for easy setup." : "Lihtsaks seadistamiseks vali eelseadistus.",
    "Apply" : "Rakenda",
    "All accounts" : "Kõik kasutajakontod",
    "Admins" : "Peakasutajad",
    "Account group: {group}" : "Kasutajakontode grupp: {group}",
    "Account management" : "Kasutajakontode haldus",
    "For performance reasons, when you enable encryption on a {productName} server only new and changed files are encrypted." : "Kui võtad {productName}i serveris krüptimise kasutusele, siis jõudlusest johtuvalt krüptitakse vaid uusi ja muudetud faile.",
    "Location" : "Asukoht",
    "Profile picture" : "Profiilipilt",
    "About" : "Teave",
    "Date of birth" : "Sünnikuupäev",
    "Full name" : "Täisnimi",
    "Additional email" : "Täiendav e-post",
    "Fediverse (e.g. Mastodon)" : "Födiversum (nt. Mastodon)",
    "Headline" : "Alapealkiri",
    "Organisation" : "Organisatsioon",
    "Phone number" : "Telefoninumber",
    "Pronouns" : "Asesõna pöördumisel",
    "Role" : "Roll",
    "X (formerly Twitter)" : "X (varem Twitter)",
    "Bluesky" : "Bluesky",
    "Website" : "Veebisait",
    "Profile visibility" : "Profiili nähtavus",
    "Locale" : "Lokaat",
    "First day of week" : "Nädala esimene päev",
    "timezone" : "ajavöönd",
    "Private" : "Privaatne",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Nähtav vaid osalejatele, kes on läbi teinud tuvastamise telefoninumbri alusel kasutades Nextcloud Talk rakendust",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Pole saadaval, sest see omadus on vajalik tuumikfunktsionaalsuse jaoks, sh failide jagamine ja kalendrikutsed",
    "Local" : "Kohalik",
    "Only visible to people on this instance and guests" : "Nähtav vaid selle serveri kasutajatele ja külalistele",
    "Federated" : "Liitpilves",
    "Only synchronize to trusted servers" : "Sünkrooni vaid usaldusväärsetesse serveritesse",
    "Not available as federation has been disabled for your account, contact your system administration if you have any questions" : "Pole saadaval, sest osalemine liitpilves on sinu kasutajakonto puhul keelatud. Lisaküsimuste korral saad teavet oma peakasutajalt",
    "Published" : "Avaldatud",
    "Synchronize to trusted servers and the global and public address book" : "Sünkrooni usaldusväärsetesse serveritesse ning üldisesse ja avalikku aadressiraamatusse",
    "Not available as publishing account specific data to the lookup server is not allowed, contact your system administration if you have any questions" : "Pole saadaval, sest kasutajakonto kohaste andmete avaldamine tuvastusserverile on keelatud. Lisaküsimuste korral saad teavet oma peakasutajalt",
    "Discover" : "Avasta",
    "Your apps" : "Sinu rakendused",
    "Active apps" : "Aktiivsed rakendused",
    "Disabled apps" : "Keelatud rakendused",
    "Updates" : "Uuendused",
    "App bundles" : "Rakenduste kogumikud",
    "Featured apps" : "Esiletõstetud rakendused",
    "Supported apps" : "Toetatud rakendused",
    "Best Nextcloud integration" : "Parim Nextcloudi lõiming",
    "Open source" : "Avatud lähtekoodiga",
    "Good performance" : "Suurepärane jõudlus",
    "Best security: documents never leave your server" : "Parim turvalisus: dokumendid ei lahku sinu serverist.",
    "Best ODF compatibility" : "Parim ühilduvus ODF-failidega",
    "Best support for legacy files" : "Parim pärandfailide tugi",
    "Good Nextcloud integration" : "Hea Nextcloudi lõiming",
    "Open core" : "Avatud lähtekoodiga tuum",
    "Best performance" : "Parim jõudlus",
    "Limited ODF compatibility" : "Piiratud ühilduvus ODF-failidega",
    "Best Microsoft compatibility" : "Parim ühilduvus Microsoftiga",
    "Show to everyone" : "Näita kõigile",
    "Show to logged in accounts only" : "Näita vaid sisseloginud kasutajatele",
    "Hide" : "Peida",
    "Manually installed apps cannot be updated" : "Käsitsi paigaldatud rakendusi ei saa uuendada",
    "{progress}% Deploying …" : "Võtan kasutusele {progress}%…",
    "{progress}% Initializing …" : "Valmendan {progress}%…",
    "Health checking" : "Korrasoleku kontroll",
    "Deploy and Enable" : "Võta kasutusele ja lülita sisse",
    "Download and enable" : "Laadi alla ja võta kasutusele",
    "Disable" : "Lülita välja",
    "Allow untested app" : "Luba testimata rakenduse kasutamine",
    "The app will be downloaded from the App Store" : "See rakendus laaditakse alla App Store'ist",
    "This app is not marked as compatible with your {productName} version." : "See rakendus pole märgitud ühilduvaks sinu {productName}i serveri versiooniga. ",
    "If you continue you will still be able to install the app. Note that the app might not work as expected." : "Kui jätkad, siis saad ta ikkagi paigaldada, aga palun arvesta, et ta ei pruugi toimida ootuspäraselt.",
    "Unknown" : "Teadmata",
    "Never" : "Mitte kunagi",
    "Could not register device: Network error" : "Seadme registreerimine polnud võimalik: võrguühenduse viga",
    "Could not register device: Probably already registered" : "Seadme registreerimine polnud võimalik: ilmselt on ta juba registreeritud",
    "Could not register device" : "Seadme registreerimine polnud võimalik",
    "An error occurred during the request. Unable to proceed." : "Päringu ajal tekkis viga. Jätkamine pole võimalik.",
    "The app has been enabled but needs to be updated." : "See rakendus on kasutusel, aga vajab uuendamist.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Viga: Kuna ta muudaks selle serveri mittetöökindlaks, siis seda rakendust ei saa sisse lülitada",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Rakendus on lubatud, aga see vajab uuendamist. Sind suunatakse 5 sekundi pärast uuendamise lehele.",
    "Do you really want to wipe your data from this device?" : "Oled sa kindel, et soovid siit seadmest oma andmed kaugkustutada?",
    "Confirm wipe" : "Kinnita kaugkustutamine",
    "Could not delete the app token" : "Rakenduse tunnusloa kustutamine ei õnnestunud",
    "Error while wiping the device with the token" : "Viga tunnusloa alusel seadmest andmete kustutamisel",
    "Error while updating device token name" : "Viga seadme tunnusloa nime uuendamisel",
    "Error while updating device token scope" : "Viga seadme tunnusloa toimeala uuendamisel",
    "Could not set group sorting" : "Grupi järjestamise määramine ei õnnestunud",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Sinu võrgust tuli liiga palju päringuid. Proovi hiljem uuesti, või võta ühendust peakasutajaga, kui tegu on veaga.",
    "Error" : "Viga",
    "Account documentation" : "Kasutajakonto juhendid",
    "Administration documentation" : "Süsteemihalduse juhendid",
    "Forum" : "Foorum",
    "Nextcloud help & privacy resources" : "Nextcloudi abiteave ja privaatsusega seotud info",
    "General documentation" : "Üldjuhendid",
    "Legal notice" : "Juriidiline teave",
    "Privacy policy" : "Privaatsusreeglid",
    "Reasons to use Nextcloud in your organization" : "Põhjused, miks peaksid Nextcloudi kasutama oma organisatsioonis",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Arendajaks on {communityopen}Nextcloudi kogukond{linkclose},  {githubopen}lähtekood{linkclose} on avaldatud {licenseopen}GNU AGPL{linkclose} litsentsi alusel.",
    "Like our Facebook page" : "Märgi meie Facebooki leht meeldivaks",
    "Follow us on Bluesky" : "Jälgi meid Bluesky's",
    "Follow us on Mastodon" : "Jälgi meid Mastodonis",
    "Check out our blog" : "Loe meie ajaveebi",
    "Subscribe to our newsletter" : "Telli meie uudiskiri",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "See Nextcloudi kogukonnaversioon pole toetatud ja kiirteavitused pole saadaval.",
    "Open documentation" : "Ava dokumentatsioon",
    "Use a second factor besides your password to increase security for your account." : "Sinu kasutajakonto turvalisuse parandamiseks kasuta lisaks oma salasõnale ka teist autentimisvõimalust.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Kui kasutad kolmanda osapoole rakenduses Nextcloudi ühendust, siis palun taga, et sa lood ja seadistad rakenduse salasõna enne kaheastmelise autentimise kasutusele võtmist.",
    "Very weak password" : "Väga nõrk salasõna",
    "Weak password" : "Nõrk salasõna",
    "So-so password" : "Enam-vähem sobiv salasõna",
    "Good password" : "Hea salasõna",
    "Strong password" : "Väga hea salasõna",
    "Group list is empty" : "Gruppide loend on tühi",
    "Unable to retrieve the group list" : "Gruppide loendi pärimine ei õnnestunud",
    "Logged in account must be a subadmin" : "Sisselogitud kasutajakonto peab olema peakasutajate alamgrupi liige",
    "- The `%1$s` HTTP header does not contain `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "- HTTP päisekirje „%1$s“ sisus puudub „%2$s“. See on võimalik turva- ja privaatsusrisk ning me soovitame, et teed vastava muudatuse.",
    "_No scheduled tasks in the last %n hour._::_No scheduled tasks in the last %n hours._" : ["Viimase %n tunni jooksul pole olnud ühtegi ajastatud ülesannet.","Viimase %n tunni jooksul pole olnud ühtegi ajastatud ülesannet."],
    "_The task pickup speed has been ok in the last %n hour._::_The task pickup speed has been ok in the last %n hours._" : ["Ülesannete töötlemise kiirus on viimase %n tunni jooksul olnud mõistlik.","Ülesannete töötlemise kiirus on viimase %n tunni jooksul olnud mõistlik."],
    "_The task pickup speed has been slow in the last %n hour. Many tasks took longer than 4 minutes to be picked up. Consider setting up a worker to process tasks in the background._::_The task pickup speed has been slow in the last %n hours. Many tasks took longer than 4 minutes to be picked up. Consider setting up a worker to process tasks in the background._" : ["Ülesannete töötlemise kiirus on viimase %n tunni jooksul olnud aeglane. Paljude ülesannete töölepanekuks kulus enam, kui 4 minutit. Palun kaalu võimalust, et ülesannete töötlemiseks seadistad taustal töötava protsessihalduri.","Ülesannete töötlemise kiirus on viimase %n tunni jooksul olnud aeglane. Paljude ülesannete töölepanekuks kulus enam, kui 4 minutit. Palun kaalu võimalust, et ülesannete töötlemiseks seadistad taustal töötava protsessihalduri."],
    "Exclude some groups from sharing" : "Välista mõned grupid jagamisest",
    "Limit sharing to some groups" : "Piira jagamist mõnede gruppidega",
    "Also allow autocompletion on full match of the user id" : "Lisaks luba automaatset täitmist kasutajatunnuse täisvaste puhul",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Sellel rakendusel pole määratud minimaalset Nextcloudi versiooni. See põhjustab tulevikus veateateid.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Sellel rakendusel pole määratud maksimaalset Nextcloudi versiooni. See põhjustab tulevikus veateateid.",
    "Loading accounts …" : "Kontode laadimine ...",
    "Set account as admin for …" : "Määra kasutajakonto peakasutajaks siin:",
    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} kasutajakonto…","{userCount} kasutajakontot…"],
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Kas seadme kadumisel või organisatsioonist lahkumisel on võimalik kaugkustutamise abil kustutada Nextcloudi andmed kõikidest „{userid}“ kasutaja seadmetest. Loomulikult toimib see vaid siis, kui vastav seade on ühendatud internetiga.",
    "Failed to load subadmin groups with details" : "Alamgruppe koos üksikasjadega ei õnnestunud laadida",
    "Loading account …" : "Laadin kasutajakontot…",
    "Adding your device …" : "Lisan sinu seadet…",
    "Developer documentation ↗" : "Dokumentatsioon arendajatele ↗",
    "Sending…" : "Saadan...",
    "Email sent" : "E-kiri on saadetud",
    "For performance reasons, when you enable encryption on a Nextcloud server only new and changed files are encrypted." : "Kui võtad Nextcloudi serveris krüptimise kasutsele, siis jõudlusest johtuvalt krüptitakse vaid uusi ja muudetud faile.",
    "{progress}% Deploying …" : "Võtan kasutusele {progress}%…",
    "{progress}% Initializing …" : "Valmendan {progress}%…",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "See rakendus pole märgitud ühilduvaks sinu Nextcloudi serveri versiooniga. Kui jätkad, siis saad ta ikkagi paigaldada, aga palun arvesta, et ta ei pruugi toimida ootuspäraselt.",
    "None/STARTTLS" : "Puudub/STARTTLS",
    "SSL" : "SSL",
    "Credentials" : "Kasutajatunnused",
    "SMTP Login" : "SMTP kasutajanimi",
    "SMTP Password" : "SMTP salasõna",
    "Save" : "Salvesta",
    "Test and verify email settings" : "Testi ja kontrolli e-posti seadistusi",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Sinu serveri turvalisuse ja jõudluse jaoks on oluline, et kõik oleks korrektselt seadistatud. Sinu aitamiseks käivitame mõned automaatsed testid ja kontrollid. Lisateavet leiad viidatud juhendist.",
    "Checking for system and security issues." : "Kontrollin süsteemivigade ja turvaprobleemide olemasolu.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Palun vaata uuesti <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">paigaldusjuhendit ↗</a> ning kontrolli <a href=\"%2$s\">logides</a> leiduvaid vigu ja hoiatusi.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Testi selle Nextcloudi serveri turvalisust <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">meie turvakontrolliga ↗</a>."
},
"nplurals=2; plural=(n != 1);");
